'use strict';

var generators = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var path   = require('path');

module.exports = generators.Base.extend({
  
  constructor: function () {
    
    generators.Base.apply(this, arguments);
    
    this.option('serviceName', { type: String, required: false });    
    this.option('imageName', { type: String, required: false });
    this.option('commands', { type: String, required: false });
    this.option('instanceCount', { type: Number, required: false }); 
    
    this.generatorConfig = {};

  }, // constructor()
  
  _isOptionSet: function(name) {
    return this.options[name] !== undefined;
  },
  
  /**
   * Prompt users for options
   */
  prompting: {
    
    askForService: function(){
 
      var done = this.async();
      var prompts = [
        
        {
          name: 'serviceName',
          message: 'Name of the application service:',
          default: 'MyService',
          when: !this._isOptionSet('serviceName')
        },
        
        {
          name: 'imageName',
          message: 'Input the Image Name:',
          when: !this._isOptionSet('imageName')
        },
        
        {
          name: 'commands',
          message: 'Commands:',
          when: !this._isOptionSet('commands')
        },
        
        {
          name: 'instanceCount',
          message: 'Number of instances of guest container application:',
          default: '1',
          when: !this._isOptionSet('instanceCount')
        },
        
      ];

      this.prompt(prompts, function(props) {
        this.props = props;
        done();
        }.bind(this)
      );
      
    } // askForService()
    
  }, // prompting()
  
  /**
   * Save configurations and configure the project
   */
  configuring: {
    
    
  }, // configuring()
  
  initializing: function () {
      this.props = this.config.getAll();
      this.projName = this.props.projName;
  }, // initializing()
  /**
   * Write the generator specific files
   */
  writing: {
    
    application: function() {
     
        this.fs.copyTpl(  this.templatePath('ApplicationManifest.xml'),
            this.destinationPath(path.join(this.projName, this.projName, 'ApplicationManifest.xml')),
            {
                appTypeName: this.projName + 'Type',
                serviceName: this.props.serviceName,
                serviceTypeName: this.props.serviceName + 'Type',
                servicePkgName: this.props.serviceName + 'Pkg',
                instanceCount: this.props.instanceCount
            }
        ); 
    }, 
    
    service: function() {
        var servicePkg = this.props.serviceName + 'Pkg';
        var serviceTypeName = this.props.serviceName + 'Type';
        var appTypeName = this.projName + 'Type';
        
        this.fs.copyTpl(  this.templatePath('Service/ServiceManifest.xml'),
            this.destinationPath(path.join(this.projName, this.projName, servicePkg, '/ServiceManifest.xml')),
            {
                serviceTypeName: serviceTypeName,
                servicePkgName: servicePkg,
                imageName: this.props.imageName,
                commands: this.props.commands
            }
        ); 
            
        this.fs.copyTpl(  this.templatePath('Service/Settings.xml'),
            this.destinationPath(path.join(this.projName, this.projName, servicePkg , '/config/Settings.xml')));
        
        this.fs.copyTpl(
            this.templatePath('deploy/install.sh'),
            this.destinationPath(path.join(this.projName, 'install.sh')),
            {
                appPackage: this.projName,
                appName: this.projName,
                appTypeName: appTypeName
            } 
        );
                
        this.fs.copyTpl(
            this.templatePath('deploy/uninstall.sh'),
            this.destinationPath(path.join(this.projName, 'uninstall.sh')),
            {
                appPackage: this.projName,
                appName: this.projName,
                appTypeName: appTypeName
            } 
        );
        
        this.fs.copyTpl(  this.templatePath('Service/code/Dummy.txt'),
            this.destinationPath(path.join(this.projName, this.projName, servicePkg , '/code/Dummy.txt')));
    }
    
  } // writing()
  
});